
rem  FILE$="MORSE"
rem  ROUTINE TO SEND MORSE CODE TO SPEAKER
rem  BY D.C. RIFE    AD2Q    2-14-85
rem  12-13-88 Made all functions subroutines.
rem  09-29-89 Added speed check and frequency inputs.
rem  04-03-95 Added F1 to interrupt program.
rem  01-19-98 Removed speed check and changed all labels to
rem           characters.  Also set speed to send " paris" 20
rem           times in 60 seconds at 20 wpm.
rem  11-17-98 Changed printing while sending a file to avoid duplicate
rem           line feeds on screen and added optional input file name
rem           to command line.  Morse will send the named file.
rem  01-19-2001 Simplified storage of CQ$.
rem  01-22-2001 Added sending of a file if named on command line.
rem  12-13-2003 Added @ character ( .--.-. ) per ITU proposal.
rem  02-12-2004 Corrected speed; it was a bit fast.
rem  01-04-2005 Added CALL$ and means of changing call.  Adjusted S1 so program
rem             will send " paris" 20 times in 60 seconds at 20 WPM.
rem  12-09-2005 Corrected starting signal code (use semicolon character) and
rem             removed "$" code per ITU-R M.1677 (2004).
rem  01-04-2008 Changed \SK to "$" character.
rem
rem  S is duration of a dot in units of clock ticks.
rem  At 24 wpm, S should be equivalent to 1/20 second.
rem  That would be about 18.2 * 24 / 20 ticks.
rem  See 1977 Handbook, page 356.
rem  When S=20 the program sounds "PARIS" 20 times in about 62 seconds.


rem  These notes added 11-16-2008
rem  From ITU-R M.1677
rem  Full stop (period)         [ . ]   . - . - . -
rem  Comma                      [ , ]   - - . . - -
rem  Colon or division sign     [ : ]   - - - . . .
rem  Question mark              [ ? ]   . . - - . .
rem  Apostrophe                 [ ' ]   . - - - - .
rem  Hyphen or dash             [ - ]   - . . . . -
rem  Fraction bar               [ / ]   - . . - .
rem  Left-hand parenthesis      [ ( ]   - . - - .
rem  Right-hand parenthesis     [ ) ]   - . - - . -
rem  Quotation marks)           [ " ]   . - . . - .
rem  Double hyphen              [ = ]   - . . . -
rem  Understood                         . . . - .
rem  Error (eight dots)                 . . . . . . . .
rem  Cross or addition sign     [ + ]   . - . - .
rem  Invitation to transmit     [ k ]   - . -
rem  Wait                               . - . . .
rem  End of work                        . . . - . -
rem  Starting signal                    - . - . -
rem  Multiplication sign        [ x ]   - . . -
rem  Commercial at              [ @ ]   .- - .- .


'   Edit next line if desired.
    CALL$ = "AD2Q"

    F$ = COMMAND$

    DIM Z(58, 9), C$(58)
    RANDOMIZE TIMER
    ON KEY(1) GOSUB QUITTER
    KEY(1) ON
    F = 800
    F0 = 32767
    S0 = 18             ' default speed
    S1 = 18.2 * 24 / 20 ' factor to convert clock ticks to speed
    S1 = 18.2           ' changed 01-04-2005

    FOR I = 1 TO 58
        READ C$(I)
        IF C$(I) = "B" THEN
            Z(I, 1) = 0
        ELSE
            Z(I, 1) = LEN(C$(I))
            FOR K = 1 TO Z(I, 1)
                IF MID$(C$(I), K, 1) = "L" THEN
                    Z(I, K + 1) = 3
                ELSE
                    Z(I, K + 1) = 1
                END IF
            NEXT K
        END IF
    NEXT I

    IF F$ = "/?" THEN
         PRINT "This program will generate the Morse Code sounds of"
         PRINT "the named text file, if any."
         PRINT "Otherwise, use the menu."
         END
         END IF

    IF LEN(F$) > 3 THEN
        S = S1 / S0
        CLS
        PRINT
        PRINT "Sending "; F$; ".  Press F1 to stop."
        PRINT
        GOSUB SEND2
        END
        END IF

MENU:
    S = S1 / S0
    CLS
    PRINT "Press F1 to interrupt program."
    PRINT
    PRINT "Speed is "; S0; " wpm"
    PRINT "Frequency is "; F; " Hz"
    PRINT "Call is ";CALL$
    PRINT
    PRINT "    MENU:"
    PRINT "End program    (0)"
    PRINT "Read keyboard  (1)"
    PRINT "Call CQ        (2)"
    PRINT "Send random    (3)"
    PRINT "Send a file    (4)"
    PRINT "Set speed      (5)"
    PRINT "Set frequency  (6)"
    PRINT "Set call       (7)"
    PRINT
    INPUT "What is your choice"; W
    IF W = 0 THEN CLS : SYSTEM: END
    IF W = 1 THEN GOSUB KEYBOARD
    IF W = 2 THEN GOSUB CALLCQ
    IF W = 3 THEN GOSUB SENDRAND
    IF W = 4 THEN GOSUB SENDFILE
    IF W = 5 THEN GOSUB SETSPEED
    IF W = 6 THEN GOSUB TONEFREQ
    IF W = 7 THEN GOSUB SETCALL
    GOTO MENU
    END

SETSPEED:
    INPUT "Speed is "; S0
    IF S0 < 1 THEN CLS : SYSTEM
    RETURN

TONEFREQ:
    INPUT "Please enter frequency in Hz "; F
    RETURN

SETCALL:
    INPUT "What is the new call";CALL$
    CALL$ = UCASE$(CALL$)
    RETURN

'   Routine to decode character and sound it
DECODE:
    IF A = 0 THEN GOTO SENDSPACE
    IF (A < 1 OR A > 58) THEN RETURN
    IF Z(A, 1) = 0 THEN RETURN
    FOR I = 1 TO Z(A, 1)
        SOUND F, S * Z(A, I + 1)
        SOUND F0, S
    NEXT I
    SOUND F0, 3 * S
    RETURN

'   SPACE
SENDSPACE:
    SOUND F0, 7 * S
    RETURN

'  Send message stored in CQ$
CALLCQ:
    CQ$ = "CQ CQ CQ DE " + UCASE$(CALL$) + "  "
    INPUT "How many calls"; N1
    FOR N = 1 TO N1
        FOR M = 1 TO LEN(CQ$)
            K$ = MID$(CQ$, M, 1)
            IF POS(0) > 72 THEN PRINT
            GOSUB LOOKUP
            GOSUB DECODE
            PRINT K$;
        NEXT M
    NEXT N
    A = 11
    GOSUB DECODE
    PRINT
    RETURN

'  Send random characters
SENDRAND:
    INPUT "How many characters do you want"; N
    IF N < 1 THEN RETURN
    Y = 0
    FOR K = 1 TO N
        Y = Y + 1
        IF Y = 6 THEN A = 0: Y = 0: K = K - 1: GOTO ADDSPACE
NEXTRND:
    A = INT(57 * RND(K)) + 2
    IF (A + 32) = 33 THEN GOTO NEXTRND
    IF (A + 32) = 35 THEN GOTO NEXTRND
    IF (A + 32) = 37 THEN GOTO NEXTRND
    IF (A + 32) = 38 THEN GOTO NEXTRND
    IF (A + 32) = 42 THEN GOTO NEXTRND
    IF (A + 32) = 43 THEN GOTO NEXTRND
    IF (A + 32) = 60 THEN GOTO NEXTRND
    IF (A + 32) = 62 THEN GOTO NEXTRND
    IF (A + 32) = 36 THEN GOTO NEXTRND

'   A = INT(43 * RND(K)) + 16
'   IF (A > 25 AND A < 33) THEN GOTO NEXTRND

ADDSPACE:
    GOSUB DECODE
    PRINT CHR$(A + 32);
    IF POS(0) > 72 THEN PRINT
    NEXT K
    GOSUB SENDSPACE
    RETURN

' Send characters from keyboard
KEYBOARD:
    PRINT "Press Esc or Ctrl Z to stop."
    PRINT "Available characters are letters, numbers, and"
    PRINT "the characters: "+CHR$(34)+" ' ( ) + , - . / : ? @ "
    PRINT "del or < is used for error"
    PRINT "+ code is same as \AR"
    PRINT "$ is used for \SK"
    PRINT "= is used for double hyphen"
    PRINT "& is used for wait"
    PRINT "; is used for starting signal"
    PRINT "READY"
GETKEY:
    K$ = INKEY$: GOSUB LOOKUP
    IF A = -1 THEN GOTO GETKEY
    IF A = -2 THEN RETURN
    GOSUB DECODE
    PRINT K$;
    IF POS(0) > 72 THEN PRINT
    GOTO GETKEY

'  Send characters from a file
SENDFILE:
    F$ = ""
    INPUT "What is the text file name"; F$
    IF F$ = "" THEN RETURN
SEND2:
    OPEN F$ FOR INPUT AS #1
    PRINT
    PRINT TIME$
    WHILE NOT EOF(1)
NEXTCHAR:
    PREV$ = K$
    K$ = INPUT$(1, #1)
    IF PREV$ = " " THEN
        IF K$ = PREV$ THEN
            PRINT " ";
            GOTO NEXTCHAR
        END IF
    END IF
    GOSUB LOOKUP
    IF A = -1 THEN GOTO NEXTCHAR
    IF A = -2 THEN GOTO CLOSEFILE
    GOSUB DECODE
    B = ASC(K$)
    IF B = 13 THEN PRINT
    IF B > 31 THEN PRINT K$;
    WEND
CLOSEFILE:
    PRINT
    PRINT TIME$
    CLOSE
    RETURN

' Convert ASCII decimal to look up row.
LOOKUP:
    IF LEN(K$) = 0 THEN A = -1: RETURN
    I = ASC(K$)
    IF I = 8 THEN I = 60           ' delete character is error
INTERPRET:
    IF I = 26 THEN A = -2: RETURN  ' stop on Ctrl Z
    IF I = 27 THEN A = -2: RETURN  ' stop on Esc
    IF I = B0 THEN A = -2: RETURN  ' stop on B$
    IF I > 122 THEN A = -1: RETURN ' omit all characters above 122
    IF I > 96 THEN I = I - 32      ' change lower case letters into upper case
    A = I - 32
    RETURN
    END

QUITTER:
    CLOSE
    RESTORE
    GOTO MENU

    '====================================================
    'ASCI-ordered CW character data
    '====================================================

    ' ASCI code  33  = character !
    DATA LSLSLL
    ' ASCI code  34  = character " quotation marks
    DATA SLSSLS
    ' ASCI code  35  = character # no code
    DATA B
    ' ASCI code  36  = character $ no code, use for \SK (end of work)
    DATA SSSLSL
    ' ASCI code  37  = character % no code
    DATA B
    ' ASCI code  38  = character & no code, use for wait
    DATA SLSSS
    ' ASCI code  39  = character ' apostrophe
    DATA SLLLLS
    ' ASCI code  40  = character ( left-hand bracket
    DATA LSLLS
    ' ASCI code  41  = character ) right-hand bracket
    DATA LSLLSL
    ' ASCI code  42  = character * no code
    DATA B
    ' ASCI code  43  = character + cross or addition sign
    DATA SLSLS
    ' ASCI code  44  = character , comma
    DATA LLSSLL
    ' ASCI code  45  = character - hyphen
    DATA LSSSSL
    ' ASCI code  46  = character . period
    DATA SLSLSL
    ' ASCI code  47  = character / fraction bar
    DATA LSSLS
    ' ASCI code  48  = character 0
    DATA LLLLL
    ' ASCI code  49  = character 1
    DATA SLLLL
    ' ASCI code  50  = character 2
    DATA SSLLL
    ' ASCI code  51  = character 3
    DATA SSSLL
    ' ASCI code  52  = character 4
    DATA SSSSL
    ' ASCI code  53  = character 5
    DATA SSSSS
    ' ASCI code  54  = character 6
    DATA LSSSS
    ' ASCI code  55  = character 7
    DATA LLSSS
    ' ASCI code  56  = character 8
    DATA LLLSS
    ' ASCI code  57  = character 9
    DATA LLLLS
    ' ASCI code  58  = character : colon or division sign
    DATA LLLSSS
    ' ASCI code  59  = character ; semicolon
    DATA LSLSL
    ' ASCI code  60  = character < error (eight dots)
    DATA SSSSSSSS
    ' ASCI code  61  = character = double hyphen
    DATA LSSSL
    ' ASCI code  62  = character > no code
    DATA B
    ' ASCI code  63  = character ?
    DATA SSLLSS
    ' ASCI code  64  = character @ arobase (per M.1677 2004)
    DATA SLLSLS
    ' ASCI code  65  = character A
    DATA SL
    ' ASCI code  66  = character B
    DATA LSSS
    ' ASCI code  67  = character C
    DATA LSLS
    ' ASCI code  68  = character D
    DATA LSS
    ' ASCI code  69  = character E
    DATA S
    ' ASCI code  70  = character F
    DATA SSLS
    ' ASCI code  71  = character G
    DATA LLS
    ' ASCI code  72  = character H
    DATA SSSS
    ' ASCI code  73  = character I
    DATA SS
    ' ASCI code  74  = character J
    DATA SLLL
    ' ASCI code  75  = character K
    DATA LSL
    ' ASCI code  76  = character L
    DATA SLSS
    ' ASCI code  77  = character M
    DATA LL
    ' ASCI code  78  = character N
    DATA LS
    ' ASCI code  79  = character O
    DATA LLL
    ' ASCI code  80  = character P
    DATA SLLS
    ' ASCI code  81  = character Q
    DATA LLSL
    ' ASCI code  82  = character R
    DATA SLS
    ' ASCI code  83  = character S
    DATA SSS
    ' ASCI code  84  = character T
    DATA L
    ' ASCI code  85  = character U
    DATA SSL
    ' ASCI code  86  = character V
    DATA SSSL
    ' ASCI code  87  = character W
    DATA SLL
    ' ASCI code  88  = character X
    DATA LSSL
    ' ASCI code  89  = character Y
    DATA LSLL
    ' ASCI code  90  = character Z
    DATA LLSS

    END

